@@ -6,7 +6,7 @@ use base qw( Alien::Base );
 use Env qw( @PATH );
 
 # ABSTRACT: Find or build patch
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 
 my $in_path;
@@ -29,6 +29,11 @@ sub exe
   $^O eq 'MSWin32' ? 'patch --binary' : 'patch';
 }
 
+sub _vendor
+{
+  shift->runtime_prop->{my_vendor};
+}
+
 
 sub alien_helper
 {
@@ -53,7 +58,7 @@ Alien::patch - Find or build patch
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
